@@ -36,7 +36,7 @@ char ichi_gokan[][3] = {"","","","","","","","","","",
 char kago[][11] = {"Ȃ","܂","","悤","","","Ȃ","","","","܂","Ȃ","","܂","ςȂ",""}; // 16
 char kag3[][11] = {"Ȃ","܂","","悤","","","Ȃ","","","","܂","Ȃ","","܂","ςȂ",""}; // 16
 char sahe[][11] = {"Ȃ","܂","","","","Ȃ","",
-		   "","","","܂","Ȃ","܂","ςȂ","","₷","","","","o","n",  "Ȃ","炵","","","A","","悤","ɂ"}; // 29
+		   "","","","܂","Ȃ","܂","ςȂ","","₷","","","","o","n",  "Ȃ","炵","","","A","","悤","ɂ","Â炢"}; // 30
 char sazu[][11] = {"Ȃ","","","","","Ȃ","","","Ȃ","",
                    "","悤"}; // 12
 char kag2[][5] = {"","","",""};
@@ -51,8 +51,8 @@ char go_i[][11] = {"܂","","","","܂",
                    "","܂","ςȂ","","₷",
                    "","ɂ","˂","","",
                    "","͂","","","","","","o","","","A"}; // 26 ܂
-char go_e[][11] = {"","Ȃ","Ȃ","","","܂","Ă","B","v"}; // 9  Kp
-char gz_e[][ 5] = {"\0","|","|","|","|","|","|","|","|"}; // 9 i͓Kp
+char go_e[][11] = {"","","Ȃ","Ȃ","","","܂","Ă","B","v"}; // 10  Kp
+char gz_e[][ 5] = {"\0","|","|","|","|","|","|","|","|","|"}; // 10 i͓Kp
 char go_o[][11] = {""}; // 1
 
 char kako[][5] = {"","","","","",""}; // 6
@@ -62,8 +62,8 @@ char genz[][3] = {"","","","","",""};
 char ke_i[][11] = {"낤","","",""}; // 4
 char keDa[][11] = {"낤","ł","ɂ","ɂ","ɂ",""}; // 6
 
-char *genSkip8 = "ɂ,Ƃ,オ,낦,悤ɂ,ߖ,܂,炩,΂,̂߂,||,낤,C^r,Ƃ͂,g,ڂW,߂,F,ɂĂ";
-char *genSkip6 = "ύX,,b,,M,],΂ߏ,ʂ,Ȃ,܂,ɂ,,߂,lC,,₦,v`,v,,Ȃ,ɂ͂,E,₢,mb,[,,S,c_,肵,F肵,ᔽ,,Ƃ,y,O,\\,S,A";
+char *genSkip8 = "ɂ,Ƃ,オ,낦,悤ɂ,ߖ,܂,炩,΂,̂߂,||,낤,C^r,Ƃ͂,g,ڂW,߂,F,ɂĂ,vƂ";
+char *genSkip6 = "ύX,,b,,M,],΂ߏ,ʂ,Ȃ,܂,ɂ,,߂,lC,,₦,v`,v,,Ȃ,ɂ͂,E,₢,mb,[,,S,c_,肵,F肵,ᔽ,,Ƃ,y,O,\\,S,A,,A";
 
 // 
 //  ł
@@ -298,7 +298,7 @@ int sahenPred()
     if(strncmp(wdw, "", 2) == 0 || strncmp(wdw, "", 2) == 0
     || strncmp(wdw, "", 2) == 0 || strncmp(wdw, "", 2) == 0
     ){
-        for(i = 0; i < 29; i++){ // sahe
+        for(i = 0; i < 30; i++){ // sahe
           if(strncmp(wdw, sahe[i], strlen(sahe[i])) == 0){
     	      ptreplace(wdw, 2, "");
 	      strcpy(jwd, "");
@@ -325,7 +325,7 @@ char *jpw;
       strncpy(cmp, jpw, ln-4);  cmp[ln-4] = '\0';
       if(strncmp(wdw, cmp, ln-4) == 0){ // Ov
  if(Dbg == 'Y') fprintf(dbg, "--- sahenKatsu --- jpw = %s cmp = %s \n", jpw, cmp);
-        for(i = 0; i < 29; i++){ // sahe
+        for(i = 0; i < 30; i++){ // sahe
           if(strncmp(wdw+ln-4, sahe[i], strlen(sahe[i])) == 0){
 	      ptreplace(wdw+ln-4, 2, "");
  if(Dbg == 'Y') fprintf(dbg, "--- sahenKatsu sahe --- jpw = %s wdw = %s \n", jpw, wdw);
@@ -463,7 +463,7 @@ int ln;
 		return(yn);
 	      }
 	    }
-            for(i = 0; i < 9; i++){ // go_e
+            for(i = 0; i < 10; i++){ // go_e
               if(strncmp(wdw+ln-2, go_e[i], strlen(go_e[i])) == 0){
 	        ptinsert(wdw+ln-2, "");
  if(Dbg == 'Y') fprintf(dbg, "--- %sKatsu go_e --- jpw = %s wdw = %s \n", mode, jpw, wdw);
@@ -581,7 +581,7 @@ char *jpw;
 
         } else
         if(strncmp(wdw+ln-2, godan_kate[j], 2) == 0){ // 
-          for(i = 0; i < 9; i++){ // go_e
+          for(i = 0; i < 10; i++){ // go_e
             if(strncmp(wdw+ln, go_e[i], strlen(go_e[i])) == 0){
 	      ptreplace(wdw+ln-2, 2, godan_syuu[j]);
  if(Dbg == 'Y') fprintf(dbg, "--- godanKatsu go_e --- jpw = %s wdw = %s \n", jpw, wdw);
@@ -1190,7 +1190,7 @@ int  ppt;
         if(ct == 1 && strncmp(wdw, jpw, strlen((char*)jpw)) != 0){ // 16/4/20
 	  hinsi[0] = *(jw+1);  hinsi[1] = '\0';
 	  if(strchr("345", *hinsi)){ //  `
-	    // if(Dbg == 'Y') fprintf(dbg, "--- diclook --- jpw = %s jew = %s \n", jpw, jew);
+	  // if(Dbg == 'Y') fprintf(dbg, "--- diclook % --- jpw = %s jew = %s \n", jpw, jew);
             if(postConj(jpw, hinsi) == 0) goto NTT;
 	    goto DICL; // 16/4/20
 	  }
